using System;

namespace Kit.Helpers.EndPoints
{
    using Microsoft.AspNetCore.Mvc;

    internal class ControllerEndPointFluent<TController> : IEndPointFluent<ControllerEndPointFluent<TController>>
        where TController : ControllerBase
    {
  
        public ControllerEndPointFluent<TController> NeedHttpGet(bool required = true)
        {
            throw new NotImplementedException();
        }

        public ControllerEndPointFluent<TController> NeedHttpPost(bool required = true)
        {
            throw new NotImplementedException();
        }

        public ControllerEndPointFluent<TController> NeedSecurityKey(string securityKeyName)
        {
            throw new NotImplementedException();
        }

        public ControllerEndPointFluent<TController> WithConstraints(object constraints)
        {
            throw new NotImplementedException();
        }

        public ControllerEndPointFluent<TController> WithDataTokens(object dataTokens)
        {
            throw new NotImplementedException();
        }

        public ControllerEndPointFluent<TController> WithDefaults(object defaults)
        {
            throw new NotImplementedException();
        }

        public ControllerEndPointFluent<TController> WithNamespaces(string[] namespaces)
        {
            throw new NotImplementedException();
        }
    }
}
