namespace Kit.Helpers.EndPoints
{
    public interface IEndPointFluent<TEndPointFluent>
    {
        TEndPointFluent NeedHttpGet(bool required = true);
        TEndPointFluent NeedHttpPost(bool required = true);
        TEndPointFluent NeedSecurityKey(string securityKeyName);
        TEndPointFluent WithDefaults(object defaults);
        TEndPointFluent WithConstraints(object constraints);
        TEndPointFluent WithNamespaces(string[] namespaces);
        TEndPointFluent WithDataTokens(object dataTokens);
    }
}